@@ -2,7 +2,7 @@ from dataclasses import dataclass
 import typing
 
 import frozendict
-from uplc import uplc_ast
+from uplc import uplc_ast, machine
 
 
 class AST:
@@ -13,7 +13,7 @@ class AST:
         raise NotImplementedError()
 
     def eval(self) -> str:
-        return self.compile().eval(frozendict.frozendict())
+        return machine.Machine(self.compile()).eval()
 
 
 @dataclass
@@ -105,7 +105,7 @@ class Integer(AST):
     x: int
 
     def compile(self):
-        return uplc_ast.Constant(uplc_ast.ConstantType.integer, self.x)
+        return uplc_ast.BuiltinInteger(self.x)
 
     def dumps(self) -> str:
         return str(self.x)
@@ -116,7 +116,7 @@ class ByteString(AST):
     x: bytes
 
     def compile(self):
-        return uplc_ast.Constant(uplc_ast.ConstantType.bytestring, self.x)
+        return uplc_ast.BuiltinByteString(self.x)
 
     def dumps(self) -> str:
         return f"0x{self.x.hex()}"
@@ -127,7 +127,7 @@ class Text(AST):
     x: str
 
     def compile(self):
-        return uplc_ast.Constant(uplc_ast.ConstantType.string, self.x)
+        return uplc_ast.BuiltinString(self.x)
 
     def dumps(self) -> str:
         return f'"{self.x}"'
@@ -138,7 +138,7 @@ class Bool(AST):
     x: bool
 
     def compile(self):
-        return uplc_ast.Constant(uplc_ast.ConstantType.bool, self.x)
+        return uplc_ast.BuiltinBool(self.x)
 
     def dumps(self) -> str:
         return "True" if self.x else "False"
@@ -147,7 +147,7 @@ class Bool(AST):
 @dataclass
 class Unit(AST):
     def compile(self):
-        return uplc_ast.Constant(uplc_ast.ConstantType.unit, ())
+        return uplc_ast.BuiltinUnit()
 
     def dumps(self) -> str:
         return "()"
